==> simplecloud-launcher-2.1.0-sources.jar: eu/thesimplecloud/launcher/console/ConsoleCompleter.kt <==
/*
 * MIT License
 *
 * Copyright (C) 2020 The SimpleCloud authors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package eu.thesimplecloud.launcher.console

import eu.thesimplecloud.launcher.startup.Launcher
import org.jline.reader.Candidate
import org.jline.reader.Completer
import org.jline.reader.LineReader
import org.jline.reader.ParsedLine
import java.util.*

/**
 * Created by IntelliJ IDEA.
 * User: Philipp.Eistrach
 * Date: 17.04.2020
 * Time: 00:17
 */
class ConsoleCompleter(private val consoleManager: ConsoleManager) : Completer {

    override fun complete(reader: LineReader, line: ParsedLine, candidates: MutableList<Candidate>) {
        val commandString = line.line()

        val suggestions = getConsoleSuggestions(commandString)
        if (suggestions.isEmpty()) {
            return
        }

        val responses = ArrayList<String>()
        responses.addAll(suggestions)

        if (responses.isNotEmpty()) {
            responses.sort()
            candidates.addAll(responses.map { Candidate(it) })
        }
    }

    private fun getConsoleSuggestions(commandString: String): List<String> {
        if (!Launcher.instance.setupManager.hasActiveSetup()) {
            return consoleManager.commandManager.getAvailableTabCompleteArgs("cloud $commandString", consoleManager.consoleSender)
        }
        return Launcher.instance.setupManager.getSetupSuggestions(commandString, consoleManager.consoleSender)
    }

}

==> simplecloud-launcher-2.8.0-pre.2-sources.jar: eu/thesimplecloud/launcher/console/ConsoleCompleter.kt <==
/*
 * MIT License
 *
 * Copyright (C) 2020-2022 The SimpleCloud authors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package eu.thesimplecloud.launcher.console

import eu.thesimplecloud.launcher.startup.Launcher
import org.jline.reader.Candidate
import org.jline.reader.Completer
import org.jline.reader.LineReader
import org.jline.reader.ParsedLine

/**
 * Created by IntelliJ IDEA.
 * User: Philipp.Eistrach
 * Date: 17.04.2020
 * Time: 00:17
 */
class ConsoleCompleter(private val consoleManager: ConsoleManager) : Completer {

    override fun complete(reader: LineReader, line: ParsedLine, candidates: MutableList<Candidate>) {
        val commandString = line.line()

        val suggestions = getConsoleSuggestions(commandString)
        if (suggestions.isEmpty()) {
            return
        }

        val responses = ArrayList<String>()
        responses.addAll(suggestions)

        if (responses.isNotEmpty()) {
            responses.sort()
            candidates.addAll(responses.map { Candidate(it) })
        }
    }

    private fun getConsoleSuggestions(commandString: String): List<String> {
        if (!Launcher.instance.setupManager.hasActiveSetup()) {
            return consoleManager.commandManager.getAvailableTabCompleteArgs(
                "cloud $commandString",
                consoleManager.consoleSender
            )
        }
        return Launcher.instance.setupManager.getSetupSuggestions(commandString, consoleManager.consoleSender)
    }

}
